==> zio-aws-lambda_2.12-5.17.125.1-sources.jar: zio/aws/lambda/model/AccountUsage.scala <==
package zio.aws.lambda.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AccountUsage(
    totalCodeSize: Option[Long] = None,
    functionCount: Option[Long] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.AccountUsage = {
    import AccountUsage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.AccountUsage
      .builder()
      .optionallyWith(totalCodeSize.map(value => value: java.lang.Long))(
        _.totalCodeSize
      )
      .optionallyWith(functionCount.map(value => value: java.lang.Long))(
        _.functionCount
      )
      .build()
  }
  def asReadOnly: zio.aws.lambda.model.AccountUsage.ReadOnly =
    zio.aws.lambda.model.AccountUsage.wrap(buildAwsValue())
}
object AccountUsage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.AccountUsage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.AccountUsage =
      zio.aws.lambda.model.AccountUsage(
        totalCodeSize.map(value => value),
        functionCount.map(value => value)
      )
    def totalCodeSize: Option[Long]
    def functionCount: Option[Long]
    def getTotalCodeSize: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("totalCodeSize", totalCodeSize)
    def getFunctionCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("functionCount", functionCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.AccountUsage
  ) extends zio.aws.lambda.model.AccountUsage.ReadOnly {
    override val totalCodeSize: Option[Long] =
      scala.Option(impl.totalCodeSize()).map(value => value: Long)
    override val functionCount: Option[Long] =
      scala.Option(impl.functionCount()).map(value => value: Long)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.AccountUsage
  ): zio.aws.lambda.model.AccountUsage.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lambda_2.12-5.20.32.2-sources.jar: zio/aws/lambda/model/AccountUsage.scala <==
package zio.aws.lambda.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AccountUsage(
    totalCodeSize: Optional[Long] = Optional.Absent,
    functionCount: Optional[Long] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.AccountUsage = {
    import AccountUsage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.AccountUsage
      .builder()
      .optionallyWith(totalCodeSize.map(value => value: java.lang.Long))(
        _.totalCodeSize
      )
      .optionallyWith(functionCount.map(value => value: java.lang.Long))(
        _.functionCount
      )
      .build()
  }
  def asReadOnly: zio.aws.lambda.model.AccountUsage.ReadOnly =
    zio.aws.lambda.model.AccountUsage.wrap(buildAwsValue())
}
object AccountUsage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.AccountUsage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.AccountUsage =
      zio.aws.lambda.model.AccountUsage(
        totalCodeSize.map(value => value),
        functionCount.map(value => value)
      )
    def totalCodeSize: Optional[Long]
    def functionCount: Optional[Long]
    def getTotalCodeSize: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("totalCodeSize", totalCodeSize)
    def getFunctionCount: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("functionCount", functionCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.AccountUsage
  ) extends zio.aws.lambda.model.AccountUsage.ReadOnly {
    override val totalCodeSize: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.totalCodeSize())
      .map(value => value: Long)
    override val functionCount: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.functionCount())
      .map(value => value: Long)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.AccountUsage
  ): zio.aws.lambda.model.AccountUsage.ReadOnly = new Wrapper(impl)
}
